@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.94 2005/07/19 16:21:31 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.97 2005/10/13 20:46:17 richb Exp $
  *
  *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -108,7 +108,7 @@ Vars v;            /* Calctool variables and options. */
  *           |  a b c d e f g h i j k l m n o p q r s t u v w x y z
  *-----------+-----------------------------------------------------
  *  Lower:   |  a b c d e f     i     l m n   p   r s t u v   x
- *  Upper:   |  A   C D E F G     J K L   N   P   R S T       X Y
+ *  Upper:   |  A   C D E F G     J K L M N   P   R S T       X Y
  *  Numeric: |  0 1 2 3 4 5 6 7 8 9
  *  Other:   |  @ . + - * / = % ( ) # < > [ ] { } | & ~ ^ ? ! :
  *           |  BackSpace Delete Return
@@ -819,16 +819,16 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     none
 },
 {
-    "    ",
-    "    ",
+    N_("Mod"),
+    N_("Modulus Division"),
     NULL,
-    { 0, 0 },
-    { 0, 0 },
-    ' ',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_M,          0 },
+    'M',
     M_NONE,
-    do_none,
-    NULL,
-    none
+    do_calc,
+    N_(" Mod "),
+    binop
 },
 {
     N_("Acc"),
@@ -877,7 +877,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     'e',
     M_NONE,
     do_expno,
-    N_("*10^"),
+    N_("e"),
     expnum
 },
 {
