@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/parser.h,v 1.5 2005/02/07 16:38:58 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/parser.h,v 1.6 2005/09/12 16:58:10 richb Exp $
  *
  *  Copyright (C) 2004-2005 Sami Pietila
  *
@@ -24,6 +24,9 @@
 
 #define ANS 1
 
+#define PARSER_ERR_INVALID_BASE		10000
+#define PARSER_ERR_TOO_LONG_NUMBER 	10001
+
 struct parser_state {
     int flags;
     char *buff;
@@ -37,4 +40,6 @@ void cp(int s[MP_SIZE], int t[MP_SIZE]);
 void ret(int s[MP_SIZE]);
 void iret(int s[MP_SIZE]);
 
+void check_numbase(char *num);
+
 #endif /*PARSER_H*/
